@@ -871,7 +871,14 @@ class DataRendererValue(object):
         self.timeBounds = timeBounds
         self.valueBounds = valueBounds
         self.scaledData = self.rescaleData(self.rawData, self.areaInfo, self.timeBounds, self.valueBounds)
-        self.coordBounds = (self.scaledData[0][0]-1, self.scaledData[-1][0]+1)
+        self.updateCoordBounds()
+
+    def updateCoordBounds(self):
+        try:
+            self.coordBounds = (self.scaledData[0][0]-1, self.scaledData[-1][0]+1)
+        except IndexError:
+            # There is no data
+            self.coordBounds = (-1, -1)
 
     def getLastObservationTime(self):
         if len(self.rawData):
@@ -881,7 +888,7 @@ class DataRendererValue(object):
     def addPoints(self, points):
         self.rawData[len(self.rawData):] = points
         self.scaledData[len(self.scaledData):] = self.rescaleData(points, self.areaInfo, self.timeBounds, self.valueBounds)
-        self.coordBounds = (self.scaledData[0][0]-1, self.scaledData[-1][0]+1)
+        self.updateCoordBounds()
 
     def changeScale(self, areaInfo, timeBounds, valueBounds=None):
         self.areaInfo = areaInfo
@@ -889,7 +896,7 @@ class DataRendererValue(object):
         if valueBounds:
             self.valueBounds = valueBounds
         self.scaledData = self.rescaleData(self.rawData, self.areaInfo, self.timeBounds, self.valueBounds)
-        self.coordBounds = (self.scaledData[0][0]-1, self.scaledData[-1][0]+1)
+        self.updateCoordBounds()
 
     def rescaleData(self, points, areaInfo, xBounds, yBounds):
         if len(points) == 0:
@@ -934,7 +941,14 @@ class DataRendererStatus(object):
         self.areaInfo = areaInfo
         self.timeBounds = timeBounds
         self.scaledData = self.rescaleData(self.rawData, self.areaInfo, self.timeBounds)
-        self.coordBounds = (self.scaledData[0][1], self.scaledData[-1][2])
+        self.updateCoordBounds()
+
+    def updateCoordBounds(self):
+        try:
+            self.coordBounds = (self.scaledData[0][1], self.scaledData[-1][2])
+        except IndexError:
+            # There is no data
+            self.coordBounds = (-1, -1)
 
     def getFirstObservationTime(self):
         if not len(self.rawData):
@@ -945,7 +959,7 @@ class DataRendererStatus(object):
         self.areaInfo = areaInfo
         self.timeBounds = timeBounds
         self.scaledData = self.rescaleData(self.rawData, self.areaInfo, self.timeBounds)
-        self.coordBounds = (self.scaledData[0][1], self.scaledData[-1][2])
+        self.updateCoordBounds()
 
     def rescaleData(self, statuses, areaInfo, xBounds):
         if len(statuses) == 0:
